The Maps extension - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# The Maps extension

The `betty.extension.Maps` extension renders interactive maps using Leaflet and OpenStreetMap.

Important

This extension requires npm.

Enable this extension in your project’s configuration file as follows:

YAML

    extensions:
      betty.extension.Maps: {}

JSON

    {
      "extensions": {
        "betty.extension.Maps": {}
      }
    }

## Configuration

This extension is not configurable.